pub struct Component(/* private fields */);Expand description
Identifies a specific plugin and atomic functionality to execute.
A component is identified by a path that specifies:
- The plugin name
- The component name within that plugin
- Optional sub-path for specific functionality
Implementations