pub struct TestCase {
pub name: String,
pub description: Option<String>,
pub input: ValueRef,
pub output: Option<FlowResult>,
}Expand description
A single test case for a workflow.
Fields
name: StringUnique identifier for the test case.
description: Option<String>Optional description of what this test case verifies.
input: ValueRefInput data for the workflow in this test case.
output: Option<FlowResult>Expected output from the workflow for this test case.