pub struct ValueRef<T = Value>(/* private fields */)
where
T: 'static;Expand description
A literal value which may be passed to a component.
This is a reference to a value owned by an Arc<serde_json::Value>.
The value is projected to a subfield of the Arc when accessed.
This is useful for avoiding cloning the value when accessing nested fields.
The value is projected to a subfield of the Arc when accessed.
Implementations
Sourceimpl ValueRef
impl ValueRef
pub fn new(value: Value) -> ValueRef
Sourcepub fn redacted<'a>(&'a self, secrets: &'a Secrets) -> RedactedValue<'a>
pub fn redacted<'a>(&'a self, secrets: &'a Secrets) -> RedactedValue<'a>
Return a redacted version of this value ref for printing.
pub fn is_truthy(&self) -> bool
Sourcepub fn resolve_json_path(&self, json_path: &JsonPath) -> Option<ValueRef>
pub fn resolve_json_path(&self, json_path: &JsonPath) -> Option<ValueRef>
Access value using a JSON path
Sourcepub fn as_object(&self) -> Option<ValueRef<Map<String, Value>>>
pub fn as_object(&self) -> Option<ValueRef<Map<String, Value>>>
Cast to an object if this value is an object
Sourcepub fn as_array(&self) -> Option<ValueRef<Vec<Value>>>
pub fn as_array(&self) -> Option<ValueRef<Vec<Value>>>
Cast to an array if this value is an array
pub fn value(&self) -> &Value
Sourcepub fn clone_value(&self) -> Value
pub fn clone_value(&self) -> Value
Clone the underlying JSON value
Sourcepub fn deserialize<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
pub fn deserialize<T>(&self) -> Result<T, Error>where
T: DeserializeOwned,
Deserialize the value into a specific type